@@ -9,7 +9,7 @@ Tk::AppWindow::Ext::Navigator - Navigate opened documents and files
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION="0.11";
+$VERSION="0.15";
 
 use base qw( Tk::AppWindow::BaseClasses::Extension );
 
@@ -22,6 +22,9 @@ use base qw( Tk::AppWindow::BaseClasses::Extension );
 
 =head1 DESCRIPTION
 
+B<Obsolete> use L<Tk::AppWindow::Ext::SideBars> instead.
+Will be removed in the next version of I<Tk::AppWindow>.
+
 Adds a tool panel to your application. By default
 it sits on the right side of your application. You
 can add items to it's notebook.
